GeneratedEventLayout

Struct GeneratedEventLayout 

pub struct GeneratedEventLayout { /* private fields */ }
Metadata describing the columns and generated particles in a generated event batch.

Implementations

Source

impl GeneratedEventLayout

pub fn new( p4_labels: Vec<String>, aux_labels: Vec<String>, particles: Vec<GeneratedParticleLayout>, vertices: Vec<GeneratedVertexLayout>, ) -> Self

Construct generated event layout metadata from p4 and auxiliary labels.

pub fn p4_labels(&self) -> &[String]

Return generated p4 column labels in dataset order.

pub fn aux_labels(&self) -> &[String]

Return generated auxiliary column labels in dataset order.

pub fn particles(&self) -> &[GeneratedParticleLayout]

Return generated particle layout entries in stable product-ID order.

pub fn particle(&self, id: &str) -> Option<&GeneratedParticleLayout>

Return the generated particle layout for a generated particle ID.

pub fn product(&self, product_id: usize) -> Option<&GeneratedParticleLayout>

Return the generated particle layout for a stable product ID.

pub fn vertices(&self) -> &[GeneratedVertexLayout]

Return generated vertex layout entries in stable vertex-ID order.

pub fn vertex(&self, vertex_id: usize) -> Option<&GeneratedVertexLayout>

Return the generated vertex layout for a stable vertex ID.

pub fn production_vertex(&self) -> Option<&GeneratedVertexLayout>

Return the production vertex layout, if the generated layout has one.

pub fn decay_products( &self, parent_product_id: usize, ) -> Vec<&GeneratedParticleLayout>

Return the generated decay daughters of a parent product ID.

pub fn production_incoming(&self) -> Vec<&GeneratedParticleLayout>

Return production-level incoming particle layouts.

pub fn production_outgoing(&self) -> Vec<&GeneratedParticleLayout>

Return production-level outgoing particle layouts.