pub struct GeneratedEventLayout { /* private fields */ }Expand description
Metadata describing the columns and generated particles in a generated event batch.
Implementations
Sourceimpl GeneratedEventLayout
impl GeneratedEventLayout
Sourcepub fn new(
p4_labels: Vec<String>,
aux_labels: Vec<String>,
particles: Vec<GeneratedParticleLayout>,
vertices: Vec<GeneratedVertexLayout>,
) -> Self
pub fn new( p4_labels: Vec<String>, aux_labels: Vec<String>, particles: Vec<GeneratedParticleLayout>, vertices: Vec<GeneratedVertexLayout>, ) -> Self
Construct generated event layout metadata from p4 and auxiliary labels.
Sourcepub fn aux_labels(&self) -> &[String]
pub fn aux_labels(&self) -> &[String]
Return generated auxiliary column labels in dataset order.
Sourcepub fn particles(&self) -> &[GeneratedParticleLayout]
pub fn particles(&self) -> &[GeneratedParticleLayout]
Return generated particle layout entries in stable product-ID order.
Sourcepub fn particle(&self, id: &str) -> Option<&GeneratedParticleLayout>
pub fn particle(&self, id: &str) -> Option<&GeneratedParticleLayout>
Return the generated particle layout for a generated particle ID.
Sourcepub fn product(&self, product_id: usize) -> Option<&GeneratedParticleLayout>
pub fn product(&self, product_id: usize) -> Option<&GeneratedParticleLayout>
Return the generated particle layout for a stable product ID.
Sourcepub fn vertices(&self) -> &[GeneratedVertexLayout]
pub fn vertices(&self) -> &[GeneratedVertexLayout]
Return generated vertex layout entries in stable vertex-ID order.
Sourcepub fn vertex(&self, vertex_id: usize) -> Option<&GeneratedVertexLayout>
pub fn vertex(&self, vertex_id: usize) -> Option<&GeneratedVertexLayout>
Return the generated vertex layout for a stable vertex ID.
Sourcepub fn production_vertex(&self) -> Option<&GeneratedVertexLayout>
pub fn production_vertex(&self) -> Option<&GeneratedVertexLayout>
Return the production vertex layout, if the generated layout has one.
Sourcepub fn decay_products(
&self,
parent_product_id: usize,
) -> Vec<&GeneratedParticleLayout>
pub fn decay_products( &self, parent_product_id: usize, ) -> Vec<&GeneratedParticleLayout>
Return the generated decay daughters of a parent product ID.
Sourcepub fn production_incoming(&self) -> Vec<&GeneratedParticleLayout>
pub fn production_incoming(&self) -> Vec<&GeneratedParticleLayout>
Return production-level incoming particle layouts.
Sourcepub fn production_outgoing(&self) -> Vec<&GeneratedParticleLayout>
pub fn production_outgoing(&self) -> Vec<&GeneratedParticleLayout>
Return production-level outgoing particle layouts.